Inspect sparse matrix dimension labels
Usage
# S3 method for class 'cudasparse'
dimnames(x)Value
NULL for an unnamed matrix, otherwise its row and column names,
following base R dimnames() semantics.
Inspect sparse matrix dimension labels
# S3 method for class 'cudasparse'
dimnames(x)NULL for an unnamed matrix, otherwise its row and column names,
following base R dimnames() semantics.